unofficial mirror of guix-patches@gnu.org 
 help / color / mirror / code / Atom feed
* [bug#47044] [PATCH] gnu: xvfb-run: Fix ‘xvfb-run --help’ in a pure environment.
@ 2021-03-10 12:14 Maxime Devos
  2021-07-08 14:43 ` bug#47044: " Mathieu Othacehe
  0 siblings, 1 reply; 2+ messages in thread
From: Maxime Devos @ 2021-03-10 12:14 UTC (permalink / raw)
  To: 47044

* gnu/packages/xorg.scm (xvfb-run)[arguments]: Refer to ‘cat’
  by absolute file name, and test whether ‘xvfb-run --help’
  succeeds in a pure environment in the ‘check’ phase.
---
 gnu/packages/xorg.scm | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/xorg.scm b/gnu/packages/xorg.scm
index 92ae6a824b..392a4f7c44 100644
--- a/gnu/packages/xorg.scm
+++ b/gnu/packages/xorg.scm
@@ -26,6 +26,7 @@
 ;;; Copyright © 2020, 2021 Michael Rohleder <mike@rohleder.de>
 ;;; Copyright © 2020 Maxim Cournoyer <maxim.cournoyer@gmail.com>
 ;;; Copyright © 2020 Jean-Baptiste Note <jean-baptiste.note@m4x.org>
+;;; Copyright © 2021 Maxime Devos <maximedevos@telenet.be>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -6799,7 +6800,7 @@ box, and a calendar.  It uses GTK+, and will match your desktop theme.")
            (lambda _
              (chmod "xvfb-run" #o755)
              (substitute* "xvfb-run"
-               (("(\\(| )(fmt|stty|awk|kill|getopt|mktemp|touch|rm|mcookie)"
+               (("(\\(| )(fmt|stty|awk|cat|kill|getopt|mktemp|touch|rm|mcookie)"
                  _ prefix command)
                 (string-append prefix (which command)))
                ;; These also feature in UI messages, so be more strict.
@@ -6808,13 +6809,15 @@ box, and a calendar.  It uses GTK+, and will match your desktop theme.")
                 (string-append prefix (which command))))))
          (replace 'check
            ;; There are no tests included.  Here we test whether we can run
            ;; a simple client without xvfb-run itself relying on $PATH.
            (lambda* (#:key tests? #:allow-other-keys)
              (when tests?
                (let ((old-PATH (getenv "PATH"))
                      (xterm (which "xterm")))
                  (unsetenv "PATH")
                  (invoke "./xvfb-run" xterm "-e" "true")
+                 (invoke "./xvfb-run" "--help")
                  (setenv "PATH" old-PATH)))))
          (replace 'install
            (lambda* (#:key outputs #:allow-other-keys)





^ permalink raw reply related	[flat|nested] 2+ messages in thread

* bug#47044: [PATCH] gnu: xvfb-run: Fix ‘xvfb-run --help’ in a pure environment.
  2021-03-10 12:14 [bug#47044] [PATCH] gnu: xvfb-run: Fix ‘xvfb-run --help’ in a pure environment Maxime Devos
@ 2021-07-08 14:43 ` Mathieu Othacehe
  0 siblings, 0 replies; 2+ messages in thread
From: Mathieu Othacehe @ 2021-07-08 14:43 UTC (permalink / raw)
  To: Maxime Devos; +Cc: 47044-done


Hey,

> * gnu/packages/xorg.scm (xvfb-run)[arguments]: Refer to ‘cat’
>   by absolute file name, and test whether ‘xvfb-run --help’
>   succeeds in a pure environment in the ‘check’ phase.

Pushed as 344316b455345485dfd60baaa88105599467fe9b.

Thanks,

Mathieu




^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2021-07-08 14:44 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -6808,13 +6809,15 @@ box, and a calendar.  It uses GTK+, and will match your desktop theme.")
          (replace 'check
            ;; There are no tests included.  Here we test whether we can run
-           ;; a simple client without xvfb-run itself relying on $PATH.
+           ;; a simple client and whether xvfb-run --help succeeds
+	   ;; without xvfb-run itself relying on $PATH.
            (lambda* (#:key tests? #:allow-other-keys)
              (when tests?
2021-03-10 12:14 [bug#47044] [PATCH] gnu: xvfb-run: Fix ‘xvfb-run --help’ in a pure environment Maxime Devos
2021-07-08 14:43 ` bug#47044: " Mathieu Othacehe

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).